@@ -71,7 +71,9 @@ class DataFrameFilterFactory:
         if not isinstance(self.columns, list):
             self.columns = [self.columns] * len(self.values)
 
-        if self.data_frame is not None:
+        is_string_filter = DataFrameFilter.is_valid_str_operator(self.operator)
+
+        if self.data_frame is not None and not is_string_filter:
             filters = []
             for column, value in zip(self.columns, self.values):
                 # Get the data type of the column
@@ -84,10 +86,11 @@ class DataFrameFilterFactory:
                     value = pd.to_datetime(value)
                 elif dtype == 'object':
                     value = str(value)
-                filters.append(DataFrameFilter(column=column, value=value, operator=self.operator, joiner=self.joiner, filter_id=self.filter_id))
+                filters.append(DataFrameFilter(column=column, value=value, operator=self.operator, joiner=self.joiner,
+                                               filter_id=self.filter_id, data_frame=self.data_frame))
             return filters
         else:
             return [DataFrameFilter(column=column, value=str(value), operator=self.operator,
                                     joiner=self.joiner, filter_id=self.filter_id,
-                                    match_case=self.match_case, regex=self.regex)
+                                    match_case=self.match_case, regex=self.regex, data_frame=self.data_frame)
                     for column, value in zip(self.columns, self.values)]
